@@ -1,9 +1,9 @@
-"""Intialize the smmap package"""
+"""Initialize the smmap package"""
 
 __author__ = "Sebastian Thiel"
 __contact__ = "byronimo@gmail.com"
-__homepage__ = "https://github.com/Byron/smmap"
-version_info = (2, 0, 3)
+__homepage__ = "https://github.com/gitpython-developers/smmap"
+version_info = (5, 0, 2)
 __version__ = '.'.join(str(i) for i in version_info)
 
 # make everything available in root package for convenience
